@@ -11,7 +11,9 @@
 #ifndef SFONT_H
 #define SFONT_H
 
-#ifdef __GNUC__
+#include <aconf.h>
+
+#ifdef USE_GCC_PRAGMAS
 #pragma interface
 #endif
 
